function [G,X0] = gen_planted_kdc(r,k, p)

% Generates the adjacency matrix G and corresponding rank k feasible
% solution X0 of a graph with planted k-disjoint-clique subgraph consisting
% of k cliques of size r (no outliers).

%% Determine block structure of G wrt r.

% Compute N.
N = sum(r);

% Initialize positions of start point of each planted clique.
c_beg = ones(k,1); 

% Set positions.
for i=2:k+1
    % Position is last position plus size of last clique.
    c_beg(i) = c_beg(i-1) + r(i-1); 
end

%% Make off-diag blocks.

% Initialize G.
G = zeros(N);

% Add edges.
for i = 1:N
    for j = (i+1): N
        % flip a coin.
        coin = rand;
        
        % If coin is "heads" add edge.
        if coin <= p
            G(i,j) = 1;
            G(j,i) = 1;
        end
    end
end


%% Insert edges for planted dense subgraphs.

X0 = zeros(N); % Initialize X0.

% Make clique blocks
for i=1:k
    % Get G.
    G(c_beg(i):(c_beg(i+1)-1), c_beg(i):(c_beg(i+1)-1)) = ones(r(i));
    
    % Get X0
    X0(c_beg(i):(c_beg(i+1)-1), c_beg(i):(c_beg(i+1)-1)) = 1/r(i)*ones(r(i));
end
